@@ -3,7 +3,8 @@
 # TODO: Make a full addColor_gui (not only for Dye)?
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 11.05.2014: Implemented new option 'Ignore case' and save user settings functions.
 # 06.05.2014: Implemented 'checkDataset'.
@@ -33,14 +34,15 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
-#' 
+#' @param parent widget to get focus when finished.
+#'  
 #' @return TRUE
 #' 
 #' @export
 #' 
 #' @seealso \code{\link{addColor}}
 
-addDye_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
+addDye_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
   
   # Global variables.
   .gData <- data.frame(No.Data=NA)
@@ -55,9 +57,17 @@ addDye_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   w <- gwindow(title="Add dye to dataset", visible=FALSE)
   
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
   
   gv <- ggroup(horizontal=FALSE,
@@ -280,5 +290,6 @@ addDye_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 } # End of GUI
