@@ -4,7 +4,8 @@
 # TODO: Option to add all uppercase/lower case marker names?
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 06.05.2014: Implemented 'checkDataset'.
 # 27.11.2013: First version.
@@ -22,14 +23,15 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
-#' 
+#' @param parent widget to get focus when finished.
+#'  
 #' @return TRUE
 #' 
 #' @export
 #' 
 #' @seealso \code{\link{addMarker}}
 
-addMarker_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
+addMarker_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
   
   # Global variables.
   .gData <- data.frame(No.Data=NA)
@@ -44,11 +46,19 @@ addMarker_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   # Main window.  
   w <- gwindow(title="Add missing markers to dataset", visible=FALSE)
 
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
-
+  
   # Vertical main group.
   gv <- ggroup(horizontal=FALSE,
                spacing=15,
@@ -280,5 +290,6 @@ addMarker_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 } # End of GUI
