@@ -3,7 +3,8 @@
 # TODO: ...
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 06.05.2014: Implemented 'checkDataset'.
 # 28.10.2013: First version.
@@ -21,6 +22,7 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
 #' 
 #' @return TRUE
 #' 
@@ -29,7 +31,7 @@
 #' @seealso \code{\link{calculateCapillary}}
 
 calculateCapillary_gui <- function(env=parent.frame(), savegui=NULL,
-                                 debug=FALSE){
+                                 debug=FALSE, parent=NULL){
   
   # Global variables.
   .gSamples <- NULL
@@ -44,9 +46,17 @@ calculateCapillary_gui <- function(env=parent.frame(), savegui=NULL,
   # Main window.
   w <- gwindow(title="Calculate capillary balance", visible=FALSE)
 
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
   
   gv <- ggroup(horizontal=FALSE,
@@ -332,5 +342,6 @@ calculateCapillary_gui <- function(env=parent.frame(), savegui=NULL,
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
