@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
 # 23.02.2014: Implemented new option 'ol.rm'.
@@ -32,12 +33,15 @@
 #' @param env environment in wich to search for data frames.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
+#' 
+#' @export
 #' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{guessProfile}}, \code{\link{checkSubset}}
 
-guessProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
+guessProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
   
   # Global variables.
   .gData <- NULL
@@ -48,11 +52,19 @@ guessProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   w <- gwindow(title="Guess profile", visible=FALSE)
 
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
-    .saveSettings()
-  })
     
+    # Save GUI state.
+    .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
+  })
+  
   gv <- ggroup(horizontal=FALSE,
                spacing=15,
                use.scrollwindow=FALSE,
@@ -314,5 +326,6 @@ guessProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
 
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 } # End of GUI
