@@ -2,12 +2,13 @@
 # TODO LIST
 # TODO: Number of decimals on x axis as an option.
 # TODO: Custom colors.
-# TODO: Just one plot button, and a dropdown to select column to sort by.
+# TODO: Just one plot button, and a dropdown to select column to sort by. Ascend/descen+numeric/character
 # TODO: ...NOT FINISHED!!!
 #      (need to change if/when a preferred dropout method has beed decided)
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
 # 15.04.2014: Fixed position_jitter height now fixed to zero (prev. default).
@@ -27,7 +28,6 @@
 # 04.06.2013: Fixed bug in 'missingCol'.
 # 17.05.2013: save plot moved to external function.
 # 17.05.2013: listDataFrames() -> listObjects()
-# 09.05.2013: First version.
 
 #' @title Plot Dropout
 #'
@@ -45,15 +45,17 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
+#' 
+# @importFrom scales pretty_breaks
+#' 
+#' @export
 #' 
 #' @return TRUE
 #' 
 #' @seealso \url{http://docs.ggplot2.org/current/} for details on plot settings.
 
-plotDropout_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
-  
-  # Load gridExtra as a temporary solution to TODO in NAMESPACE.
-  loadPackage(packages=c("gridExtra"))
+plotDropout_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
   
   # Global variables.
   .gData <- NULL
@@ -68,11 +70,19 @@ plotDropout_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   # Main window.  
   w <- gwindow(title="Plot dropout data", visible=FALSE)
   
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
-
+  
   # Vertical main group.
   gv <- ggroup(horizontal=FALSE,
                spacing=8,
@@ -1233,5 +1243,6 @@ plotDropout_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
