@@ -3,7 +3,8 @@
 # TODO: ...
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
 # 20.01.2014: Changed 'saveImage_gui' for 'ggsave_gui'.
@@ -24,13 +25,15 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
+#' 
+# @importFrom plyr count
+#' 
+#' @export
 #' 
 #' @return TRUE
 
-plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
-
-  # Load gridExtra as a temporary solution to TODO in NAMESPACE.
-  loadPackage(packages=c("gridExtra"))
+plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
 
   # Global variables.
   .gData <- NULL
@@ -50,11 +53,19 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   # Main window.
   w <- gwindow(title="Plot peaks", visible=FALSE)
   
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
-
+  
   gv <- ggroup(horizontal=FALSE,
                spacing=8,
                use.scrollwindow=FALSE,
@@ -504,5 +515,6 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
