@@ -3,7 +3,8 @@
 # TODO: ...
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
 # 06.02.2014: Fixed button locks when error.
@@ -24,13 +25,16 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
+#' 
+#' @export
 #' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{tablePrecision}}, \code{\link{checkSubset}}
 
 tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
-                                 debug=FALSE){
+                                 debug=FALSE, parent=NULL){
   
   # Global variables.
   .gData <- data.frame(Columns="NA")
@@ -49,9 +53,17 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
   # Main window.
   w <- gwindow(title="Calculate summary statistics for precision", visible=FALSE)
 
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
   
   gv <- ggroup(horizontal=FALSE,
@@ -687,5 +699,6 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
