@@ -4,7 +4,8 @@
 
 # NB! Can't handle Sample.Names as factors?
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 07.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 14.01.2014: Removed requirement for column 'Sample.Name'.
 # 20.11.2013: Specified package for function 'gtable' -> 'gWidgets::gtable'
@@ -37,13 +38,17 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
+#' 
+#' @export
 #' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{trim}}
 
 
-trim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
+trim_gui <- function(env=parent.frame(), savegui=NULL,
+                     debug=FALSE, parent=NULL){
 
   # Global variables.
   .gData <- data.frame(Sample.Name="NA")
@@ -55,11 +60,19 @@ trim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   # Main window.
   w <- gwindow(title="Trim dataset", visible=FALSE)
   
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
-
+  
   # Vertical main group.
   gv <- ggroup(horizontal=FALSE,
               spacing=5,
@@ -603,5 +616,6 @@ trim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
